@@ -46,7 +46,7 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def AgentTransferMoney(self, request):
@@ -69,7 +69,7 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def AssignClientsToSales(self, request):
@@ -95,7 +95,7 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def AuditApplyClient(self, request):
@@ -118,7 +118,7 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreatePayRelationForClient(self, request):
@@ -141,7 +141,7 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeAgentAuditedClients(self, request):
@@ -164,7 +164,7 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeAgentBills(self, request):
@@ -187,7 +187,7 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeAgentClientGrade(self, request):
@@ -210,7 +210,7 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeAgentClients(self, request):
@@ -233,7 +233,7 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeAgentDealsByCache(self, request):
@@ -256,53 +256,7 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeAgentDealsCache(self, request):
-        """【该接口已下线，请使用升级版本DescribeAgentDealsByCache】代理商拉取缓存的全量客户订单
-
-        :param request: Request instance for DescribeAgentDealsCache.
-        :type request: :class:`tencentcloud.partners.v20180321.models.DescribeAgentDealsCacheRequest`
-        :rtype: :class:`tencentcloud.partners.v20180321.models.DescribeAgentDealsCacheResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeAgentDealsCache", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeAgentDealsCacheResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeAgentPayDeals(self, request):
-        """【该接口已下线，请切换使用升级版本DescribeAgentPayDealsV2】可以查询代理商代付的所有订单
-
-        :param request: Request instance for DescribeAgentPayDeals.
-        :type request: :class:`tencentcloud.partners.v20180321.models.DescribeAgentPayDealsRequest`
-        :rtype: :class:`tencentcloud.partners.v20180321.models.DescribeAgentPayDealsResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeAgentPayDeals", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeAgentPayDealsResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeAgentPayDealsV2(self, request):
@@ -325,30 +279,30 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def DescribeAgentSelfPayDeals(self, request):
-        """【该接口已下线，请切换使用升级版本DescribeAgentSelfPayDealsV2】可以查询代理商下指定客户的自付订单
+    def DescribeAgentRelateBigDealIds(self, request):
+        """根据大订单号查询关联申请合并支付的其他订单号
 
-        :param request: Request instance for DescribeAgentSelfPayDeals.
-        :type request: :class:`tencentcloud.partners.v20180321.models.DescribeAgentSelfPayDealsRequest`
-        :rtype: :class:`tencentcloud.partners.v20180321.models.DescribeAgentSelfPayDealsResponse`
+        :param request: Request instance for DescribeAgentRelateBigDealIds.
+        :type request: :class:`tencentcloud.partners.v20180321.models.DescribeAgentRelateBigDealIdsRequest`
+        :rtype: :class:`tencentcloud.partners.v20180321.models.DescribeAgentRelateBigDealIdsResponse`
 
         """
         try:
             params = request._serialize()
             headers = request.headers
-            body = self.call("DescribeAgentSelfPayDeals", params, headers=headers)
+            body = self.call("DescribeAgentRelateBigDealIds", params, headers=headers)
             response = json.loads(body)
-            model = models.DescribeAgentSelfPayDealsResponse()
+            model = models.DescribeAgentRelateBigDealIdsResponse()
             model._deserialize(response["Response"])
             return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeAgentSelfPayDealsV2(self, request):
@@ -371,32 +325,7 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeClientBalance(self, request):
-        """已提供新接口并推进切换，白名单禁用控制访问观察后无反馈，可以下线
-
-        【该接口将逐步下线，请切换使用升级版本DescribeClientBalanceNew】为合作伙伴提供查询客户余额能力。调用者必须是合作伙伴，只能查询自己名下客户余额.
-
-        :param request: Request instance for DescribeClientBalance.
-        :type request: :class:`tencentcloud.partners.v20180321.models.DescribeClientBalanceRequest`
-        :rtype: :class:`tencentcloud.partners.v20180321.models.DescribeClientBalanceResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeClientBalance", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeClientBalanceResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeClientBalanceNew(self, request):
@@ -419,7 +348,53 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeClientJoinIncreaseList(self, request):
+        """查询合作伙伴名下客户的参与增量激励考核信息列表
+
+        :param request: Request instance for DescribeClientJoinIncreaseList.
+        :type request: :class:`tencentcloud.partners.v20180321.models.DescribeClientJoinIncreaseListRequest`
+        :rtype: :class:`tencentcloud.partners.v20180321.models.DescribeClientJoinIncreaseListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeClientJoinIncreaseList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeClientJoinIncreaseListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeClientSwitchTraTaskInfo(self, request):
+        """查询客户的交易类型切换任务的信息，查询成功则获取当前用户的切换链接，查询失败则返回失败的原因
+
+        :param request: Request instance for DescribeClientSwitchTraTaskInfo.
+        :type request: :class:`tencentcloud.partners.v20180321.models.DescribeClientSwitchTraTaskInfoRequest`
+        :rtype: :class:`tencentcloud.partners.v20180321.models.DescribeClientSwitchTraTaskInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeClientSwitchTraTaskInfo", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeClientSwitchTraTaskInfoResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeRebateInfos(self, request):
@@ -442,7 +417,7 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeRebateInfosNew(self, request):
@@ -465,7 +440,7 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeSalesmans(self, request):
@@ -488,7 +463,7 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeUnbindClientList(self, request):
@@ -511,7 +486,7 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyClientRemark(self, request):
@@ -534,7 +509,7 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def RemovePayRelationForClient(self, request):
@@ -557,4 +532,4 @@ class PartnersClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
\ No newline at end of file
+                raise TencentCloudSDKException(type(e).__name__, str(e))
\ No newline at end of file
