@@ -26,6 +26,29 @@ class TrocketClient(AbstractClient):
     _service = 'trocket'
 
 
+    def ChangeMigratingTopicToNextStage(self, request):
+        """修改迁移中的Topic状态进入下一步
+
+        :param request: Request instance for ChangeMigratingTopicToNextStage.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.ChangeMigratingTopicToNextStageRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.ChangeMigratingTopicToNextStageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ChangeMigratingTopicToNextStage", params, headers=headers)
+            response = json.loads(body)
+            model = models.ChangeMigratingTopicToNextStageResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateConsumerGroup(self, request):
         """创建消费组
 
@@ -371,6 +394,29 @@ class TrocketClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteSmoothMigrationTask(self, request):
+        """删除平滑迁移任务，只有被取消的任务才可删除
+
+        :param request: Request instance for DeleteSmoothMigrationTask.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DeleteSmoothMigrationTaskRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DeleteSmoothMigrationTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteSmoothMigrationTask", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteSmoothMigrationTaskResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteTopic(self, request):
         """删除主题
 
@@ -394,6 +440,29 @@ class TrocketClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeConsumerClient(self, request):
+        """查询消费者客户端详情
+
+        :param request: Request instance for DescribeConsumerClient.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeConsumerClientRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeConsumerClientResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeConsumerClient", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeConsumerClientResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeConsumerGroup(self, request):
         """查询消费组详情
 
@@ -902,6 +971,77 @@ class TrocketClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeMigratingGroupStats(self, request):
+        """查看迁移消费组的实时信息
+
+        :param request: Request instance for DescribeMigratingGroupStats.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeMigratingGroupStatsRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeMigratingGroupStatsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeMigratingGroupStats", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeMigratingGroupStatsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeMigratingTopicList(self, request):
+        """查询Topic迁移状态列表
+
+        查询过滤器，支持TopicName、MigrationStatus、Namespace查询
+
+        :param request: Request instance for DescribeMigratingTopicList.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeMigratingTopicListRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeMigratingTopicListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeMigratingTopicList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeMigratingTopicListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeMigratingTopicStats(self, request):
+        """用于查询迁移主题的实时数据
+
+        :param request: Request instance for DescribeMigratingTopicStats.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeMigratingTopicStatsRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeMigratingTopicStatsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeMigratingTopicStats", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeMigratingTopicStatsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeProductSKUs(self, request):
         """查询产品售卖规格，针对 RocketMQ 5.x 集群。
 
@@ -929,6 +1069,7 @@ class TrocketClient(AbstractClient):
         """查询角色列表，Filter参数使用说明如下：
 
         1. RoleName，角色名称模糊搜索
+        2. AccessKey，AccessKey模糊搜索
 
         :param request: Request instance for DescribeRoleList.
         :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeRoleListRequest`
@@ -950,6 +1091,35 @@ class TrocketClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeSourceClusterGroupList(self, request):
+        """平滑迁移过程获取源集群group列表接口
+
+        查询过滤器，支持字段
+        GroupName，消费组名称模糊搜索
+        Imported，是否已导入
+        ImportStatus，导入状态
+        Namespace，命名空间
+
+        :param request: Request instance for DescribeSourceClusterGroupList.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeSourceClusterGroupListRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeSourceClusterGroupListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSourceClusterGroupList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSourceClusterGroupListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeTopic(self, request):
         """查询主题详情，Offset和Limit参数是指订阅该主题的消费组查询分页参数，Filter参数使用说明如下：
 
@@ -1001,6 +1171,54 @@ class TrocketClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeTopicListByGroup(self, request):
+        """根据消费组获取主题列表，Filter参数使用说明如下：
+
+        TopicName，主题名称过滤
+
+        :param request: Request instance for DescribeTopicListByGroup.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeTopicListByGroupRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeTopicListByGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeTopicListByGroup", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeTopicListByGroupResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DoHealthCheckOnMigratingTopic(self, request):
+        """检查迁移中的主题是否处于正常状态，只有处于正常状态的主题，才可以进入下一个迁移阶段
+
+        :param request: Request instance for DoHealthCheckOnMigratingTopic.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DoHealthCheckOnMigratingTopicRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DoHealthCheckOnMigratingTopicResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DoHealthCheckOnMigratingTopic", params, headers=headers)
+            response = json.loads(body)
+            model = models.DoHealthCheckOnMigratingTopicResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ImportSourceClusterConsumerGroups(self, request):
         """导入消费者组列表
 
@@ -1093,6 +1311,29 @@ class TrocketClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyInstanceEndpoint(self, request):
+        """修改 RocketMQ 5.x 集群接入点。
+
+        :param request: Request instance for ModifyInstanceEndpoint.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.ModifyInstanceEndpointRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.ModifyInstanceEndpointResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyInstanceEndpoint", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyInstanceEndpointResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyMQTTInsPublicEndpoint(self, request):
         """更新MQTT实例公网接入点
 
@@ -1255,6 +1496,29 @@ class TrocketClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RemoveMigratingTopic(self, request):
+        """从迁移列表中移除主题，仅当主题处于初始状态时有效
+
+        :param request: Request instance for RemoveMigratingTopic.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.RemoveMigratingTopicRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.RemoveMigratingTopicResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RemoveMigratingTopic", params, headers=headers)
+            response = json.loads(body)
+            model = models.RemoveMigratingTopicResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ResendDeadLetterMessage(self, request):
         """重新发送死信消息
 
@@ -1271,6 +1535,52 @@ class TrocketClient(AbstractClient):
             model = models.ResendDeadLetterMessageResponse()
             model._deserialize(response["Response"])
             return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ResetConsumerGroupOffset(self, request):
+        """重置消费位点
+
+        :param request: Request instance for ResetConsumerGroupOffset.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.ResetConsumerGroupOffsetRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.ResetConsumerGroupOffsetResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ResetConsumerGroupOffset", params, headers=headers)
+            response = json.loads(body)
+            model = models.ResetConsumerGroupOffsetResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def RollbackMigratingTopicStage(self, request):
+        """回滚正在迁移的主题至前一个阶段
+
+        :param request: Request instance for RollbackMigratingTopicStage.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.RollbackMigratingTopicStageRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.RollbackMigratingTopicStageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RollbackMigratingTopicStage", params, headers=headers)
+            response = json.loads(body)
+            model = models.RollbackMigratingTopicStageResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
